Опыт российской библиографии Сопикова, 3-я часть - "Л" | Аделанта
Description: Лучший справочник книжного антиквара: Опыт российской библиографии Сопикова В.С. или Полный словарь сочинений и переводов на славянском и русском языках, от заведения типографий до 1813 года
Keywords: Сопиков, Опыт российской библиографии

Аделанта Выставка-продажа частной коллекции антикварных книг +7 (495) 725 89 08 |  | Из книжного собрания Александра Лугачева
| Главная |  | Каталог книг |  | Древние книги |  | История древних книг |  | Старинные книги |  | Антикварные книги |  | Купим |  | Доставка |  | Архив сделок |
Путь: | Главная / Куплю старые книги, антикварные издания, домашние библиотеки, рукописи / Опыт российской библиографии Сопикова, 3-я часть - "Л"
### Опыт российской библиографии, или полный словарь сочинений и переводов, напечатанных на славенском и российском языках от начала заведения типографий до 1813 года 5864. Лабиринт волшебства, или удивительные приключения восточных принцев, сочинение В. Протопоповича; Москва, 1786 г. - в 8°. 5865. Лакировальщик, или ясное и подробное наставление о заготовлении, составлении и употреблении разного рода спиртовых и масленых лаков, и фирназов для живописцев, иконописцев, гравировальщиков, маляров, каретников, слесарей, бронзовщиков, табакерошников, и прочих всякого рода ремесленников; собрано из разных иностранных и российских практических записок Н. Осиповым; Санкт-Петербург, 1798 г. - в 12°. 5866. Лактанция Фирмиана, нареченного христианским Цицероном, божественных наставлений семь книг, писанных к Константину Великому, - первому Христианскому Императору, с присовокуплением 10 о гневе Божием; 2) о удивительном строении человека, и 3) о кончине гонителей христианства, перевел с латинского Иван Тредьяковский; 2 части; Москва, 1783 г. - в 8°. 5867. Ламберта Босия, краткое описание правления Афинской республики; перевел с латинского прокурор Иван Мошков; Санкт-Петербург, 1779 г. - в 8°. 5868. Ламех и Цилла, Идиллия г. Геснера; перевод с немецкого; Санкт-Петербург, 1774 г. - в 8°. 5869. Лангедокская путешественница, или приключение г-жи Дитри; перевод с французского; 2 части; Москва, 1801 г. - в 8°. 5870. Ландшафт моих воображений; сочинение А. Кропотова; Санкт-Петербург, 1803 г. - в 12°. 5871. Ларчик (сокровище хранительный) для всех влюбленных и желающих вступить в брак, и проч., сочинение младшего Богатского; перевод с немецкого; Москва, 1803 г. - в 12°. 5872. Латинская учебная книга, с французского переводом; Москва, 1809 г. - в 8°. 5873. Латинские первоначальные слова; Санкт-Петербург - в 8°. 5874. Лаура, или поцелуй в своих действиях; сочинение г. Геснера; перевод с немецкого; Москва, 1784 г. - в 8°. 5875. Леандр (бедный), или автор без риторики, сочинение Николая Брусилова; Санкт-Петербург, 1805 г. - в 12°. 5876. Левсил, русский богатырь; российское сочинение в стихах, подражание Илье Муромцу; Санкт-Петербург, 1807 г. - в 12°. 5877. Легкомыслов, получивший здравый рассудок, отрывки ироид, и стихотворение г. Адиссона на Ризвикский мир; перевод с французского; Санкт-Петербург, 1777 г. - в 8°. 5878. Леонард и Термилия, или злорадная судьба двух любовников, перевод с французского; Москва, 1784 г. - в 8°. 5879. Лекарство (верное) от подагры, перевел с французского Василий Вороблевский; Москва, 1779 г. - в 8°. 5880. Лекарство (верное) от предубеждения умов; перевел с немецкого Михаил Антоновский; Санкт-Петербург, 1798 г. - в 12°. 5881. Лекарство для болящей души, или правила, открывающие путь к достижению царствия небесного, собранные из разных писателей, а особенно из сочинения Фомы Кемпийского, под названием о последовании Иисусу Христу, Иваном Михайловым; Москва, 1799 г. - в 12°. 5882. Лекарство от задумчивости и бессонницы, или настоящие русские сказки; Санкт-Петербург, 1786 г. - в 8°. 5883. То же, издание второе; Санкт-Петербург, 1793 г. - в 8°. 5884. Лекарство от праздности и скуки, или забавное препровождение праздного времени угадывать на картах; Москва, 1792 г. - в 8°. 5885. Лекарственник, или избранное врачебное веществословие, показывающее употребительнейшие, как простые, так и составные лекарства, действующие различным образом в теле человеческом, сочиненный г. Пернером; перевод с латинского; Москва, 1791 г. - в 8°. 5886. Лекарь (псовый), или описание собачьих болезней, с показанием вернейших и надежнейших средств для лечения их; перевел с немецкого Н.О.; Санкт-Петербург, 1792 г. - в 8°. 5887. Лексикон (географический) Российского Государства, сочиненный Ф. Полуниным, изданный г. Миллером; Москва, 1773 г. - в 8°. 5888. Лексикон (полный географический), содержащий в себе по азбучному порядку подробное описание всех частей света, собранный г. Лангером; 3 части; Москва, 1791 г. - в 12°. 5889. Лексикон вояжеров французский с немецким и латинским, содержащий в себе все слова французского языка, также все в науках, художествах и ремеслах употребительные названия, собственные имена людей, земель, городов, морей и рек; переложенный на российский язык Сергеем Волчковым; 2 тома; Санкт-Петербург, 1755-1768 гг. - в 8°. 5890. То же, издание второе, исправленное; 2 части; Санкт-Петербург, 1778 г. - в 4°. 5891. То же, издание третье, дополненное, в трех частях; Санкт-Петербург, 1795 г. - в 4°. 5892. Лексикон (иконологический), или руководство к познанию живописного и разного художества, медалей, эстампов, с описанием, взятым из разных древних и новых стихотворцев, и проч.; перевод с французского; Санкт-Петербург, 1763 г. - в 8°. 5893. То же, издание второе; Санкт-Петербург, 1786 г. - в 8°. 5894. Лексикон греко-российско-французский, издал Греческого Московского монастыря Иеромонах Досифей Кома; 2 части; Москва, 1810 г. - в 4°. 5895. Лексикон латино-иллирический, и немецко-венгерский; сочинение г. Ямбрисиха; Заграбия, 1742 г. - в 4°. 5896. Лексикон латинский Целляриев, с российским и немецким переводом; Санкт-Петербург, 1742 г. - в 8°. 5897. То же, издание второе; Санкт-Петербург, 1768 г. - в 8°. 5898. То же, издание третье; Санкт-Петербург, 1781 г. - в 8°. 5899. То же, издание четвертое; Санкт-Петербург, 1794 г. - в 8°. 5900. То же, нового издания; Москва, в типографии Священного Синода, 1810 г. - в 8°. 5901. Лексикон (латинский) Геснеров, с российским переводом, и с приложением реестра по азбучному порядку российских слов; Москва, 1768 г. - в 8°. 5902. То же, издание второе; Москва, 1780 г. - в 8°. 5903. То же, издание третье, вновь исправленное и умноженное прибавлением греческих слов, профессором Дмитрием Синковским; 3 части; Москва 1796 г. - в 8°. 5904. Лексикон латинский, с российским переводом, из лучших латинских писателей собранный Фомою Розоновым; Москва, 1797 г. - в 8°. 5905. То же, издание второе; Москва, 1805 г. - в 8°. 5906. То же, издание третье, исправленное и дополненное; Москва, 1808 г. - в 8°. Сей Лексикон есть точный перевод латино-французского Будотова Лексикона. 5907. Лексикон, или словарь немецко-российский и российско-немецкий, сочиненный Иваном Геймом; 2 части; Рига, 1801 г. - в 8°. 5908. То же, издание второе; Лейпциг, 1803-1805 гг. - в 8°. 5909. Лексикон (новый), на немецком, французском, латинском, итальянском и российском языках, изданный М. Гавриловым; Москва, 1781 г. - в 8°. 5910. То же, издание второе; Москва, 1789 г. - в 8°. 5911. Лексикон немецкий Вейсманов, с латинским, переложенный на российский язык Сергеем Волчковым; Санкт-Петербург, 1731 г. - в 4°. 5912. То же, издание второе, вновь пересмотренное и умноженное; Санкт-Петербург, 1781 г. 5913. То же, издание третье; Санкт-Петербург, 1799 г. - в 4°. 5914. Лексикон любовный; перевод с французского; Санкт-Петербург, 1768 г. - в 8°. 5915. То же, издание второе; Москва, 1779 г. - в 8°. 5916. Лексикон исторический, географический, политический и гражданский Российского Государства; сочинение В.Н. Татищева; 3 части; Санкт-Петербург, 1793 г. - в 8°. 5917. Лексикон немецкий и российский (полный), из большого грамматикально-критического словаря г. Аделунга, составленный обществом ученых людей; 2 части; Санкт-Петербург, 1798 г. - в 8°. Начальная цена 10 рублей, но ныне гораздо дороже. 5918. Лексикон польский (общий), или библейный словарь, сочиненный К. Кондратовичем; Санкт-Петербург, 1775 г. - в 4°. 5919. Лексикон простого греческого языка, с российским переводом; Москва, 1783 г. - в 8°. 5920. Лексикон (новый), или словарь пятизначный, на французском, итальянском, немецком, латинском и российском языках, содержащий в себе полное собрание всех употребительных французских слов, с точным их на другие четыре диалекта переводом и объяснением различных знаменований и всех грамматических слову приличествуют, сообразно словарю французского академии; изданный И. Соцом; 2 части; Москва, 1784-1786 гг. - в 4°. 5921. Лексикон (краткий) Венерониев, на французском, итальянском, немецком и латинском языках; Москва, 1771 г. - в 8°. 5922. Лексикон (краткий) мифологический; сочинение Михайла Чулкова; Санкт-Петербург, 1767 г. - в 8°. 5923. Лексикон по алфавиту российских слов о разных произрастаниях, то есть о древах, травах, цветах, семенах, огородных и полевых кореньях; перевел с латинского К. Кондратович; Санкт-Петербург, 1781 г. - в 8°. 5924. Лексикон российский с немецким, и немецкий с российским; изданный Яковом Родде; 2 части; Рига, 1784 г. - в 8°. 5925. Лексикон российский с немецким и латинским; сочиненный г. Гелтергофом; 2 части; Москва, 1778 г. - в 8°. 5926. Лексикон, или Целляриус Российский, с немецким переводом; издан. Г. Гелтергофом; Москва, 1771 г. - в 8°. 5927. Лексикон, или Целляриус немецкий, с российским переводом; изданный Г. Гелтергофом; Москва, 1765 г. - в 8°. 5928. Лексикон российский и французский, в котором находятся почти все слова российского алфавита; 2 части; Санкт-Петербург, 1762 г. 5929. Лексикон французский Целляриус, с приложением по алфавиту российским слов; изданный г. Гелтергофом; Москва, 1769 г. - в 8°. 5930. То же, издание второе; Москва, 1782 г. - в 8°. 5931. Лексикон (новый полный), французско-российский, с последнего издания лексикона Французского Академии переведенный собраниям ученых людей; издан иждивением Ивана Вейтбрехта; 2 части; Санкт-Петербург, 1786 г. - в 4°. 5932. То же, издание второе, исправленное и дополненное И. Татищевым; 2 части; Санкт-Петербург, 1798 г. - в 8°. Сей перевод, противу французского подлинника, весьма не полон. 5933. Лексикон рифмальный, или славяно-российского витийства словарь, сочинено Иваном Тодорским; Москва, 1800 г. - в 4°. Сей книги видел я первый только лист напечатанный, а издана ли она вся, неизвестно. 5934. Лексикон французского (сокращенный), с российским переводом; издан Иваном Новиковым; Москва, 1802 г. - в 8°. 5935. Лекции Петра Рахманова о диффиренциальном исчислении; издано Николаем Тенигиным; Санкт-Петербург, 1810 г. - в 8°. 5936. Лекции о разных предметах, касающихся до механики, гидравлики и гидростатики, как то матери и ее свойствах, о центральных силах, о механических силах, о мельницах, о тяжелых колесах, о машине колотить сваи, и о гидравлических и гидростатических машинах вообще; соч. г. Фергуссоном; перевод с английского Льва Собакина, с присовокуплением к ним собственной переводчика лекции о огненных машинах, с фигурами; Санкт-Петербург, 1787 г. - в 8°. 5937. Лекции о огненных машинах; сочинено механиком Львом Собакиным, с фигурами; Москва, 1788 г. - в 8°. Помещена также при конце переведенной им книги: Лекции о разных предметах, и проч. 5938. Лемана ( I ) пробирное искусство, перевод с немецкого; Санкт-Петербург, 1775 г. - в 8°. 5939. Его же, о фосфорах, их разном приготовлении, пользе и проч., перевод с нем.; Санкт-Петербург, 1780. 5940. Ленвиль, или сыновняя горячность. 5941. Леокадия, испанская повесть, сочинение Флориана, перевод с французского; Санкт-Петербург, 1794 г. - в 8°. Оной же перевод Павла Львова, помещен во 2 части Приятного препровождения времени. 5942. Лесажа сочинения: Бакалавр Саламанский, или похождение Дона Херубина де ла Ронда; перевод с французского Андрея Нартова; 2 части; Санкт-Петербург, 1763 г. - в 8°. 5943. Лесажа сочинения: Повесть о хромоногом бесе; переведена с французского Дмитрием Легким и Дмитрием Мокеевым; 2 части; Санкт-Петербург, 1775 г. - в 8°. 5944. То же, издание второе; Санкт-Петербург, 1775 г. - в 8°. 5945. То же, издание третье; Санкт-Петербург, 1785 г. - в 8°. 5946. Лесажа сочинения: Похождение Жильблаза де Сантилланы; перевел с французского Василий Теплов; 4 части; Санкт-Петербург, 1754 г. - в 8°. Это первое издание сей книги, оно лучшее из всех. 5947. То же, издание второе; Санкт-Петербург, 1761 г. - в 12°. 5948. То же, издание третье; Санкт-Петербург, 1768 г. - в 12°. 5949. То же, издание четвертое; Санкт-Петербург, 1775 г. - в 12°. 5950. То же, издание пятое; Санкт-Петербург, 1783 г. - в 12°. 5951. То же, издание шестое; Санкт-Петербург, 1792 г. - в 12°. 5952. То же, издание седьмое; Санкт-Петербург, 1801 г. - в 12°. Это издание из всех самое худшее. 5953. То же, издание восьмое; Санкт-Петербург, 1808 г. - в 12°. 5954. Лесажа сочинения: Похождение Естеванилла Гонсалеса, прозванного весельчаком, перевод с французского; 2 части; Санкт-Петербург, 1765 г. - в 8°. 5955. Леста, или днепровская русалка, романтическая повесть; вольный перевод с немецкого; 4 части; с картинками; Москва, 1806 г. - в 12°. 5956. Летучая мышь, комическая повесть; перевод с немецкого; Москва, 1805 г. - в 12°. 5957. Лечебник (детский); сочинение славного Монтпельерского врача в пользу детей; перевод с французского; 2 части; Москва, 1793 г. - в 8°. 5958. Лечебник, или практическая карманная книга для врачей, особенно полковых; сочинение доктора и профессора Геккера; перевел с немецкого лекарь Мартын Бруннер; Москва, 1840 г. - в 12°. 5959. Лечебник (детский краткий домашний), сочинение Г. Гинтера; Москва, 1802 г. - в 12°. 5960. Лечебник (домашний), или простой способ лечения болезней, сочинено Х. Пекеном, перевел с немецкого Алексей Протасов; Санкт-Петербург, 1765 г. - в 8°. Потом многократно вновь был издаваем в Санкт-Петербурге и единожды в Москве. 5961. То же, исправленный и знатно дополненный Матвеем Пекеном; 2 части; Москва, 1797 г. - в 8°. 5962. Лечебник (карманный конский, опытный русский), состоящий из 160 простых, дешевых и лучших лекарств; Москва, 1807 г. - в 12°. 5963. Лечебник (карманный), содержащий в себе краткое, но ясное описание признаков, причин и способов, к излечению внутренних и наружных болезней, приключающихся телу человеческому, с показанием действий и приемов сложных и простых лекарств, выбран из славных врачей, и по алфавиту расположен доктором г. Эллиотом; переведен с английского на российский язык, с присовокуплением своих рецептов, и по алфавиту российскому распределен г. Пищековым; Санкт-Петербург, 1790 г. - в 8°. 5964. То же, издание второе; Санкт-Петербург, 1794 г. - в 12°. 5965. Лечебник, или наставления, относительный к деятельной врачебной науке; сочинено бароном Штерком, для пользы лекарей, находящихся в армиях и небольших городах; перевод с латинского; 2 части; Москва, 1789 г. - в 8°. 5966. Лечебник, или подробное описание любострастных болезней и врачевания их, сочинение доктора Сезана; перевод с французского Петра Виноградского; Москва, 1809 г. - в 12°. 5967. Лечебник (конский), или совершенное наставление, как и чем вылечивать часто бывающие конские болезни, собрано из разных авторов; Москва, 1800 г. - в 12°. 5968. Лечебник (опытный конский) или с успехом испытанные лекарства; Москва, 1796 г. - в 12°. 5969. Лечебник (полный и всеобщий домашний), сочиненный как для предохранения здравия надежнейшими средствами, так и для пользования болезней всякого рода, с показанием причин, признаков, и более того распознавательных, и проч., англинское сочинение Г. Бухана; перевод с французского; 5 частей; Москва, 1790-1791 гг. - в 4°. 5970. То же, издание второе; 5 частей; Санкт-Петербург, 1809-1813 гг. - в 4°. 5971. Лечебник (полный и всеобщий), или полное и полезное врачебное наставление всех возможных признаков, всех причин и разных средств к излечению всяких как внутренних, так и наружных болезней, сочинение Г. Рибеля, переведено с латинского Ф. Барсук-Моисеевым; 7 частей, с 24 анатомическими фигурами; Москва, 1791 г. - в 8°. 5972. Лечебник простонародный, содержащий в себе пользования разных часто приключающихся болезней домашними лекарствами, без помощи лекаря, и важнейшие наставления о предупреждении их, и хранении всего здоровья, перевод с французского князя П. Енгалычева; Москва, 1799 г. - в 8°. 5973. То же, издание второе; Москва, 1801 г. - в 8°. 5974. То же, издание третье; Москва, 1808 г. - в 8°. 5975. Лечебник сельский, или словарь врачевания болезней, бываемых в роде человеческом, также в роде скотском и птиц домашних; собранный М. Чулковым; 5 частей; Москва, 1789-1790 гг. - в 4°. Сие сочинение не окончено; оно расположено азбучным порядком и доведено только до буквы «П». 5976. Лечебник лошадиный, или рецепты для излечения лошадей от болезней; Санкт-Петербург, 1778 г. - в 12°. 5977. Лечебник конский (русский), содержащий познание конских признаков, статей, лет, ковки и анатомии болезней конских и лечения их; собирание к тому нужных трав, составления сложных лекарств, наставление подробное к содержанию конского завода, и проч., сочинение Г. Эвеста; 2 части; Москва, 1795 г. - в 8°. 5978. То же, издание второе; Москва, 1809 г. - в 8°. 5979. Лечебник (новый полный методический) конский, и других домашних животных, как то: овец, коз, свиней, собак, кошек и домашних птиц, собранный из разных вернейших сочинителей, с собственными некоторыми примечаниями, и расположенный правильным образом, и изданный лекарем Иваном Андреевским; 3 части; Москва, 1793 г. - в 8°. 5980. Лечебник скотский, или показание средств, служащих к излечению всяких в домашнем скоте и птицах, а особенно в лошадях случающихся болезней; сочинено г. Фишером; перевод с немецкого; Москва, 1774 г. - в 8°. 5981. То же, издание второе; Москва, 1788 г. - в 8°. 5982. Лечение сапа и воссы, отчет, данный обществу земледелия Сенского Департамента г. Колленем, перевод с французского; Москва, 1812 г. - в 8°. 5983. Либман, немецкая повесть, из сочинений Г. Арнода; перевод с французского Моисея Смирнова; Санкт-Петербург, 1781 г. - в 12°. 5984. Либо пан, либо пропал, или удивительная жизнь и тридцатилетнее заключение Иоанна Норкроса, одного английскогоийского капитана, самим им писанная в темнице, перевод с немецкого; Москва, 1796 г. - в 8°. 5985. Лекей, или круг словесности, древней и новой; сочинение Г. Ла Гарпа; переведенный с французского Членами Российской Академии; 5 частей; Санкт-Петербург, 1810-1814 гг. - в 8°. Первую часть переводил Петр Карабанов, вторую и третию – Петр Соколов, четвертую – Александр Никольский, пятую – Дмитрий Соколов. 5986. Лилия, российская повесть, взятая из недавно случившегося происшествия; сочинение А. Попова; Москва, 1802 г. - в 8°. 5987. Ликующая Россия в дни мира с Портой Оттоманской, стихотворение; Санкт-Петербург, 1792 г. - в 4°. 5988. Лира, или собрание разных в стихах сочинений и переводов некоторого муз любителя (И. Богданова); Санкт-Петербург, 1774 г. - в 4°. 5989. Лира, то есть собрание стихотворений В.Б.; Москва, 1804 г. - в 12°. 5990. Лира (пустынная) забвенного сына природы; сочинение И.В.; Санкт-Петербург, 1807 г. - в 8°. 5991. Лобах, счастливый отец, разговорная повесть, сочиненная младшим Шлейснером; перевод с немецкого; Москва, 1803 г. - в 8°. 5992. Логика Аббата Кондильяка; перевел с французского Ал. Гронский, с фигурами; Санкт-Петербург, 1792 г. - в 8°. 5993. Логика, или умственная наука, руководствующая к достижению истины; сочинение Аббата Кондильяка, перевел с французского Тимофей Осиповский; Москва, 1805 г. - в 8°. Это друое сочинение сго автора, совсем различное от предыдущего. 5994. Логика и риторика, кратким и для детского возраста удобопонятным образом расположенная, и в пользу юношества изданная Александром Никольским; Санкт-Петербург, 1790 г. - в 8°. 5995. Логика (краткая), или умословие, служащая в пользу российского юношества; переведена с немецкого г. Андреяновским; Москва, 1788 г. - в 8°. 5996. Логика (краткая), изданная магистром Петром Богдановым; Москва, 1806 г. - в 12°. 5997. Логика, или умственная наука, т.е. прямое употребление разума в исследовании истины, со многими правилами для предохранения себя от заблуждения как в учении, так и в общей жизни; сочинение Г. Ватса; перевод с французского; Санкт-Петербург, 1807 г. - в 8°. 5998. Логика (общенародная), или исследование науки умственной, приноравливаясь общему познанию людей; перевод с немецкого; Москва, 1789 г. - в 8°. 5999. Логика и риторика для дворян, изданная Г. Мочульским; Москва, 1789 г. - в 8°. 6000. Логика, или умственная наука; Москва, 1809 г. - в 8°. 6001. Логика и риторика (краткая), для учащихся в российских духовных училищах; Москва, 1803 г. - в 8°. 6002. Логика (краткая), или умословие, служащее в пользу российского юношества; Москва, 1788 г. - в 12°. 6003. Лодоик, или нравственные наставления для пользы и увеселения юношества; перевел с французского Николай Анненский; 2 части; Санкт-Петербург, 1799 г. - в 8°. 6004. Ложные друзья; перевод с французского; Москва, 1807 г. - в 12°. 6005. Ложный похититель Мальтийского Ордена, кавалер д’Аббевиль, истинная повесть, перевел с французского Василий Псиол; Москва, 1786 г. - в 8°. 6006. Ложный Петр III, или жизнь, характер и злодеяния бунтовщика Емельки Пугачева, в 2 частях, с его портретом; перевод с немецкого; Москва, 1809 г. - в 12°. Французский подлинник сего сочинения напечатан в Амстердаме в 1776 году. 6007. Ложный похититель царской власти, азиатская повесть; перевод с французского; 2 части; Москва, 1807 г. - в 12°. Другое заглавие, см. Паша, или удары случая и фортуны. 6008. Лоимология, или описание моровой язвы, ее существа, происшествия, причин, поражения и производства припадков, с показанием образа предохранения и врачевания этой скорби; сочинение Ивана Виена; Санкт-Петербург, 1787 г. - в 4°. 6009. Локка (Иоанна), о воспитании детей; перевел с французского профессор Николай Поповский; 2 части; Москва, 1760 г. - в 8°. 6010. То же, издание второе; Москва, 1788 г. - в 8°. 6011. Ломмера, о роговой дуге, или новом виде серебряной руды; перевод с немецкого; Санкт-Петербург, 1780 г. - в 8°. 6012. Ломоносова сочинения: Древняя Российская История, от начала народа до кончины Великого князя Ярослава I или до 1054 года; Санкт-Петербург, 1766 г. - в 4°. Немецкий перевод Хр. Бакмейстера, Рига, 1763 г. - в 8°. Французский перевод с немецкого Бакмейстерова Г-на Эйду, Париж, 1769 г. - в 8°. 6013. Ломоносова сочинения: Краткий российский летописец, с родословием царствующего дома; Санкт-Петербург, 1760 г. - в 8°. Немецкий перевод Якова Штелина, Рига, 1767 г. - в 8°. И вторично, там же, 1771 г. - в 8° 6014. Ломоносова сочинения: Краткое руководство красноречию, или риторика; Санкт-Петербург, 1748 г. - в 8° 6015. То же, издание второе, исправленное сочинителем; Москва, 1759 г. - в 4°. Это лучшее издание сей книги. 6016. То же, нового издания; Санкт-Петербург, 1778 г. - в 8°. 6017. То же, издание шестое; Санкт-Петербург, 1791 г. - в 8°. 6018. То же, издание восьмое; Санкт-Петербург, 1805 г. - в 8°. 6019. То же, издание девятое; Санкт-Петербург, 1810 г. - в 8°. 6020. Первые основания металлургии, или рудных дел; с фигурами; Санкт-Петербург, 1763 г. - в 8°. 6021. То же, издание второе; Санкт-Петербург, 1791 г. - в 8°. 6022. Ломоносова сочинения: Письмо поздравительное Императрице Екатерине II, на возвращение из Лифляндии; Санкт-Петербург, 1764 г. - в 4°. 6023. Ломоносова сочинения: Поэма (ироническая) Петр Великий, песнь I и II; Санкт-Петербург, 1760 г. - в 4°. 6024. Ломоносова сочинения: Рассуждение о жидкости и твердости тел; Санкт-Петербург, 1749 г. - в 4°. Латинский перевод, Санкт-Петербург, 1760 г. - в 4°. 6025. Ломоносова сочинения: Рассуждение о большей точности морского пути; Санкт-Петербург, 1751 г. - в 4°.Латинский перевод, Санкт-Петербург, 1759 г. - в 4°. 6026. Ломоносова сочинения: Слово похвальное Императрице Елизавете Петровне; Санкт-Петербург, 1749 г. - в 4° и 8°. Латинский перевод самого сочинителя помещен во 2 части его сочинения московского издания. 6027. Ломоносова сочинения: Слово о пользе химии; Санкт-Петербург, 1751 г. - в 4°. Латинский перевод Г. Козицкого, Санкт-Петербург, 1751 г. - в 4°. 6028. Ломоносова сочинения: Слово о явлениях воздушных, от электрической силы происходящих; с фигурами; Санкт-Петербург, 1753 г. - в 4°. Латинский перевод, Санкт-Петербург, 1754 г. - в 4°. 6029. Ломоносова сочинения: Слово похвальное Императору Павлу Великому; Санкт-Петербург, 1755 г. - в 4° и 8°. Французский перевод Барона Чуди, помещен во 2-й части его сочинений Московского издания. 6030. Ломоносова сочинения: Слово о происхождении света, новую теорию о цветах представляющее; Санкт-Петербург, 1756 г. Латинский перевод, Санкт-Петербург, 1761 г. - 4°. 6031. Ломоносова сочинения: Слово о рождении металлов от трясения земли; Санкт-Петербург, 1757 г. Латинский перевод, Санкт-Петербург, 1757 г. - 4°. 6032. Ломоносова сочинения: Собрание разных сочинений, в стихах и прозе; книга первая; Санкт-Петербург, 1751 г. - в 8°. 6033. То же, издание второе, с прибавлениями, с портретом автора и фигурами; Москва, 1757 г. - в 4°. В сем издании помещены шесть слов, говоренных им в торжественных Академических собраниях. 6034. То же, издание третье, книга 1 и 2; Санкт-Петербург, 1758 г. - в 8°. 6035. То же, издание четвертое; Санкт-Петербург, 1768 г. - в 8°. В сих двух изданиях находятся все его стихотворения, а из прозаических сочинений только два похвальных слова – Императрице Елисавете Петровне и Императору Петру Великому. Первая книга сих сочинеий потом неоднократно в Санкт-Петербурге вновь была издаваема. 6036. Ломоносова сочинения: Собрание разных сочинений, в стихах и прозе, собрано и издано ректором Московской Академии Архимандритом Дамаскиным; 3 части, с портретом автора; Москва, 1778 г. - в 8°. 6037. То же, издание второе; Санкт-Петербург, 1803 г. - в 8°. В сем издании помещен перевод его: Описание кометы. 6038. Ломоносова сочинения: Собрание (полное) всех сочинений, в стихах и прозе, с приобщением жизни сочинителя, и с прибавлением еще нигде не напечатанных творений; 6 частей; с фигурами; Санкт-Петербург, 1784-1787 гг. - в 4°. 6039. То же, издание второе; Санкт-Петербург, 1795-1797 гг. - в 4°. 6040. То же, издание третье; Санкт-Петербург, 1803-1804 гг. - в 4°. Первое издание добротою бумаги и чистотою оттиска преимущественнее двух последних. 6041. Ломоносова сочинения: Трагедия Демофонт, в 5 действиях; Санкт-Петербург, 1750 г. - в 8°. 6042. Ломоносова сочинения: Трагедия Темира и Селим, в 5 действиях; Санкт-Петербург, 1751 г. - в 8°. 6043. Лорензо Старк, семейственная картина; сочинение Г. Энгеля; перевод с немецкого; 2 части; Москва, 1808 г. - в 8°. 6044. Лоримон, или человек, каков он есть; сочинение Г. Арнода, перевод с французского; 6 частей; с картинками; Москва, 1810 г. - в 12°. 6045. Лохера (Максимилиана), практические наблюдения, которые производил он в больнице святого Марка над любострастной болезнью, с ее ужасными припадками, пользованной без произведения селевации или слюнотечения, и проч., перевел с латинского Фома Барсук Моисеев; Москва, 1790 г. - в 8°. 6046. Лоция, или морской предводитель, содержащий в себе описание фарватеров и входов в порты в Финском заливе, Балтийском море, Зунде и Скагераке находящихся; сочинено в 1750 году морским капитаном А. Нагаевым; 2 части; Санкт-Петербург, 1789 г. - в 8°. 6047. Лоция Категата, содержащий описание маяков, промеров, банок и мелей, вместе с планами разных гаваней, проспектов и видов берега, переведенные с английского С. Сполоховым; Санкт-Петербург, 1806 г. - в 4°. 6048. Лоция, или морской путеводитель по Азовскому и Черному морям; сочинение флота капитана-лейтенанта И. Будищева; Санкт-Петербург, 1808 г. - в 4°. 6049. Луиза Г***, или торжество невинности, истинная повесть, перевод с немецкого; 2 части; Москва, 1787 г. - в 8°. 6050. Луиза, или хижина среди мхов; перевод с французского; 2 части; Москва, 1791 г. - в 8°. 6051. Луиза, или власть добродетели женского пола, нравоучительная повесть; перевел с французского Иван Шальт; Санкт-Петербург, 1780 г. - в 8°. 6052. Лукиана Самосатянина, разговоры мертвых, переведены с греческого И. Сидоровским и П. Похомовым; 3 части; Санкт-Петербург, 1775 г. - в 8°. 6053. Луцилия, или Арендарка маленького Доминика, нравоучительная сказка, перевела с французского Катерина Воейкова; Москва, 1781 г. - в 8°. 6054. Луция и Мелания, или две великодушные сестры, сочинение Г. Арнода; перевел с французского Авраам Оболенский; Москва, 1782 г. - в 8°. 6055. Лучи мудрости, или нравоучительные и полезные рассуждения Сенеки и Плутарха, и прочих славных в древности мужей; перевод с латинского; 2 части; Москва, 1786 г. - в 8°. 6056. Луч благодати, или писания Н.А. Краевича, с надписью: Божия никтоже весть, точию Дух Божий; с изображением надгробного памятника; Москва - в 8°. Без означения года. Редка. 6057. Лучшие часы моей жизни; сочинение Марьи Поспеловой; Владимир, 1798 г. - в 8°. 6058. Лучшие места из разных греческих писателей, собранные профессором Матвеем; перевел с греческого студент Михайло Дмитриевский; Москва, 1807 г. - в 8°. 6059. Лестница умственного восхождения к Богу, по степеням созданных вещей, сочинение Кардинала Баллармина; перевел с латинского Тимофей Мальгин; Санкт-Петербург, 1786 г. - в 8°. 6060. Летние прогулки, или нравоучительные и забавные беседы для детей; на французском и российском языках; Москва, 1806 г. - в 8°. 6061. Летописец, или русский племянник, содержащий российскую историю от Р.Х. с 862 по 1681 год; 2 части; Москва, 1790 г. - в 4°. 6062. Летописец (древний), содержащий в себе: повесть происшествий, бывших в России при владении 14 Великих князей, сперва Владимирских, потом Московских через 125 лет, начиная от времен княжения Великого князя Александра Ярославовича Невского, до княжения Великого князя Василия Дмитриевича; 2 части; Санкт-Петербург, 1774 г. - в 4°. 6063. Летописец Нестеров, с продолжением по Кениксбергскому списку, или Российская библиотека, содержащая в себе древние летописи и всякие записки, способствующие к объяснению Истории и Географии Российской древних и средних времен, издал Иван Барков; часть 1; Санкт-Петербург, 1767 г. - в 4°. Немецкий перевод оного Г. Шерера, в Лейпциге, 1774 г. - в 4°. Другой перевод Иеромонаха Семенова (Дамаскина), издан Гаттегером в Геттингене. 6064. Летописец Новгородский, начинающийся от 1017 до 1353 года продолжающийся; Москва, 1781 г. - в 4°. 6065. Летописец польский (с 964 по 1764 год), или хронологическое изображение происшествий Королевства Польского, с включением как Российской, так и других сопредельных держав, краткой Истории, с приобщением табелей, содержащих супруг и детей королевских, так и кончину владетелей, так же современных Государей всей Европы, Польских Архиепископов и Епископов, государственных министров, полководцев и ученых людей; перевел с французского И. Одинцов; Санкт-Петербург, 1782 г. - в 8°. 6066. Летописец (русский) от пришествия Рюрика до кончины Царя Иоанна Васильевича; издал Н. Львов; 5 частей; Санкт-Петербург, 1792 г. - в 8°. 6067. Летописец Соловецкого монастыря; Москва, 1790 г. - в 8°. 6068. Летописец, содержащий в себе Российскую Историю с 1206 до 1634 года; Москва, 1734 г. - в 4°. 6069. Летописец, содержащий Российскую историю с 852 до 1598 года, именуемой Архангелогородский; Москва, 1781 г. - в 4°. 6070. Летописец турецкий и сарацинский Г. Дрехслера, исправленный и умноженный Г. Хемницким, с прибавлением г. Розина; перевод с латинского; Москва, 1788 г. - в 8°. 6071. Летописец (нравственный), содержащий Российскую Историю от царствования Великого князя В.В. Мономаха до покорения Новгорода; Санкт-Петербург, 1772 г. - в 4°. 6072. Летопись Московская (краткая); сочинение Ал. Сумарокова; Санкт-Петербург, 1774 г. - в 8°. 6073. Летопись (краткая) Малой России, настоящего образа тамошнего правления, с прибавлением списка преждебывших гетманов, генеральных старшин, полковников и иерархов, с показанием городов, рек, монастырей, церквей, числа людей и проч., собрано и издано Васильем Рубаном; Санкт-Петербург, 1779 г. - в 12°. 6074. Летопись о многих мятежах и о разорении Москвы от внутренних и внешних неприятелей; Санкт-Петербург, 1773 г. - в 8°. 6075. То же, издание второе; Москва, 1778 г. - в 8°. 6076. Летопись о Северной Истории, или о Государствах Датском, Российском, Гведском, Польском, Прусском, Курляндском, и проч., с особенными примечаниями на умоначертание, нравы и обычаи этих народов, на свойство и естественные произведения их климата; сочинено Г. Лакомбом; перевел с французского г. Иваном; часть 1; Санкт-Петербург, 1794 г. - в 8°. Французский подлинник сей книги в 2 частях, но на русском более не издано. В сей первой части содержится история только о Датском Королевстве. 6077. Летопись (подробная) от начала России до Полтавской баталии; издал Николай Львов; 4 части; Санкт-Петербург, 1798-1799 гг. - в 8°. 6078. Летопись (русская) по Никонову списку; 8 частей; Санкт-Петербург, 1762-1792 гг. - в 4°. 6079. Летопись Российская по списку Софийскому Великого Новгорода, в продолжение издаваемых манускриптов при Академии Наук; часть 1-я; Санкт-Петербург, 1795 г. - в 4°. 6080. Летопись русская с Воскресенского списка, подаренного Патриархом Никоном в 1658 году; 2 части; Санкт-Петербург, 1793 г. - в 4°. 6081. Летопись святого отца нашего Димитрия Митрополита, Ростовского Чудотворца, сказующая деяния от начала миробытия до Рождества Христова, собранная из Божественного Писания, из различных хронографов и историкографов греческих, славянских, римских, польских, еврейских и иных; Москва, 1784 г. - в 8°. 6082. То же, издание второе, в двух частях; с портретом сочинителя; Санкт-Петербург, 1796 г. - в 8°. 6083. То же, издание третье; Москва, 1800 г. - в 8°. Второе издание напечатано с рукописи, писанной собственною рукою Святителя Димитрия, и с дополнением, взятым из другого списка. 6084. Летопись Царствования Императрицы Екатерины II, сочинение Г. Шторха, перевел с немецкого Г. Глинка; часть 1-я, содержащая законодательство; Санкт-Петербург, 1801 г. - в 8°. 6085. Любимец фортуны; перевел с французского Иван Захаров; 2 части; Москва, 1782 г. - в 8°. 6086. Любим и Лиза, или жизнь добродетельных супругов; с картинкой; Москва, 1803 г. - в 12°. 6087. Любовники и супруги, или мужчины и женщины; издал Г. Громов; Санкт-Петербург, 1798 г. - в 8°. 6088. Любовники (несчастные), или истинные приключения графа Коминжа, наполненные событий жалостных, и нежные сердца чрезвычайно трогающих; перевод с французского Я. Княжнина; Санкт-Петербург, 1771 г. - в 12°. 6089. Любовники, сосланные в Сибирь, или приключение Петра Великого; исторический роман, с картинками; 2 части; Москва, 1809 г. - в 12°. 6090. То же, другой перевод; Москва, 1809 г. - в 12°. 6091. Любовники философы, или страсть предводимая рассуждением; перевод с французского; 2 части; Москва, 1766 г. - в 8°. 6092. То же, издание второе; Москва, 1778 г. - в 8°. 6093. Любовники (несчастные), пастушеская повесть, российское сочинение П.С.; Санкт-Петербург, 1809 г. - в 8°. 6094. Любовник соперник, или поверенный сам себе; повесть, сочиненная г-жой Гомец, перевод с французского; Санкт-Петербург, 1766 г. - в 8°. 6095. Любовник (несчастный), или приключения Вильгельма фон М…, дворянина из нижней Саксонии; перевел с немецкого Козьма Дараган; Санкт-Петербург, 1791 г. - в 8°. 6096. Любовные утехи, сочиненные для графини де Ж… графом де С… на счет прекрасного пола; перевод с французского; Москва, 1780 г. - в 8°. 6097. Любовь Аназелугеда и Уардии, или несчастные приключения двух любовников судьбой гонимых, арабская повесть, с картинкой; перевод с французского Н. Зубрилова; Москва, 1791 г. - в 8°. 6098. Любовь без успеха, или Инесса Кордуанская, испанская повесть, с прибавлением повести о разрыве брака между Абенамором и Фатимой; перевод с французского; Санкт-Петербург, 1764 г. - в 8°. 6099. Любовь безуспешная несчастного кавалера Шарленильского, и чудные его приключения, перевод с немецкого; Москва, 1785 г. - в 8°. 6100. Любовь (братняя) и матерняя ненависть, или слепая любовь Солимана, Императора Турецкого, и плачевная смерть двух сыновей его; перевод с французского Д.О.; Москва, 1794 г. - в 8°. 6101. Любовь (Божия прославленная), или рассуждение о истинной премудрости и истинном благе, взятое из откровенного света Божия благодати, писания и здравого рассудка; перевод с французского; Москва, 1786 г. - в 12°. 6102. Любовь в полной своей силе, или несчастное приключение Карла и Амалии; перевел с немецкого П.М.; Москва, 1794 г. - в 8°. 6103. Любовь (горестная) Маркиза де Толедо; перевел с испанского Ф. Эмин; Санкт-Петербург, 1764 г. - в 8°. 6104. Любовь Генриха IV к наукам; перевод с французского; Санкт-Петербург, 1808 г. - в 8°. 6105. Любовь (героическая), или примеры чрезвычайного в любви постоянства, великой и мужественной решимости в терпении всяких бедствий, неоспоримо доказывающие твердость женского духа; перевод с французского; 2 части; Москва, 1805 г. - в 12°. 6106. Любовь Зефира и Флоры, с прибавлением двух идиллий Аглаи, или благодеяние, и Элианы, или гробница; перевод с французского, с фронтисписом; Москва, 1806 г. - в 16°. 6107. Любовь и действие ее; Москва, 1780 г. - в 8°. 6108. Любовь и мир, или возбуждение к любви и миру с радостью совершившегося мира между жителями града; сочинение Осташковского Протоиерея Андрея Колоколова; Москва, 1801 г. - в 8°. 6109. Любовь Исмены и Исмениаса; перевод с французского; Москва, 1769 г. - в 12°. 6110. Любовь, лирическое сочинение Максима Невзорова; Санкт-Петербург, 1803 г. - в 12°. 6111. Любовь Кариты и Полидора, или редкие приключения двух язычников; сочинение на греческом языке с коего на французского перевел г. Бартелеми, с него на российский Денис Фонвизин; Москва, 1763 г. - в 12°. 6112. То же, другой перевод Василья Заозерского; Москва, 1790 г. - в 8°. 6113. Любовь, книжка золотая, издал Глеб Громов; Санкт-Петербург, 1798 г. - в 8°. 6114. Любовь, ненависть и мщение, или история двух знатных английскогоийских фамилий; перевел с французского А. Клименко; 2 части; Москва, 1805 г. - в 16°. 6115. Любовь (несчастная), перевод с французского; Санкт-Петербург, 1779 г. - в 8°. 6116. Любовь (несчастная), или приключения одной весталки, перевод с немецкого; Москва, 1793 г. - в 8°. 6117. Любовь Перианда и Феномены, исполненная нежных для чувствительных сердец приключений, перевод с французского; Москва, 1787 г. - в 8°. 6118. Любовь (постоянная) Евдона и Берфы, с приобщением повести о разбойнике Барбосе; Москва, 1787 г. - в 8°. 6119. Любовь Палирия и Дирьфии, перевел с французского Степан Лобысевич; Санкт-Петербург, 1774 г. - в 12°. 6120. Любовь (превратная), или приключения миледи графини Англезей; перевел с французского Иван Метальников; Санкт-Петербург, 1779 г. - в 8°. 6121. Любовь Псиши и Купидона; сочинение Г. де Лафонтена; перевел с французского Федор Дмитриев-Мамонов, с присовокуплением его сочинения, под названием: Дворянин философ; с фигурами; Москва, 1769 г. - в 8°. Редка. 6122. Любовь Сафои и Фаона; перевод с французского; Москва, 1780 г. - в 8°. 6123. Любовь сильнее дружбы, повесть испанская, перевод с французского; Санкт-Петербург, 1764 г. - в 8°. 6124. Любовь (увенчанная), или приключения Мелентеса и Арианны, одной знаменитой сицилианки; перевод с французского; 4 части; Москва, 1792 г. - в 8°. 6125. Любовь (увенчанная), или приключения д’Аблинкурта и девицы де Сент-Симон; перевод с французского; Москва, 1782 г. - в 8°. 6126. Любовь (совершенная), иносказательная повесть, сочиненная для тех, кто могут ее пользоваться, или разуметь пользу ее, служащая иным сказкой, иным приятным упражнением, а для других нравственным поучением, А.Л.; Москва, 1790 г. - в 8°. 6127. Любовь (супружеская), или история виконта Дежетнона, сочинение графа С., перевел с французского П. Толченов; Москва, 1788 г. - в 8°. 6128. Любовь к отечеству, стихи; соч. г. Взметнева; Санкт-Петербург, 1812 г. - в 4°. 6129. Любомудрие против мнимых страхов смерти, переведено с латинского Протоиереем И. Красовским; Санкт-Петербург, 1796 г. - в 8°. Читать старинную книгу дальше
| Реставрация старых книг |  | Оценка старинных книг |  | Энциклопедия букиниста |  | Русские писатели |  | Библиотека Ивана Грозного |  | История русских книг |